@@ -1,10 +1,14 @@
 from airflow.sensors.external_task import ExternalTaskSensor, ExternalTaskMarker
 
 
-def task_name(parent_id, child_id):
-    parent_name = ".".join(parent_id.split(".")[-2:])
+def edge_to(child_id):
     child_name = ".".join(child_id.split(".")[-2:])
-    return f"{parent_name}--TO--{child_name}"
+    return f"--NOTIFY--{child_name}"
+
+
+def edge_from(parent_id):
+    parent_name = ".".join(parent_id.split(".")[-2:])
+    return f"--WAIT_FOR--{parent_name}"
 
 
 def subscribe_to(dag_id, parent_dag_ids, timeout=600, allowed_states=['success'], failed_states=['failed', 'skipped'],
@@ -12,9 +16,9 @@ def subscribe_to(dag_id, parent_dag_ids, timeout=600, allowed_states=['success']
     tasks = []
     for parent_id in parent_dag_ids:
         tasks.append(ExternalTaskSensor(
-            task_id=task_name(parent_id, dag_id),
+            task_id=edge_from(parent_id),
             external_dag_id=parent_id,
-            external_task_id=task_name(parent_id, dag_id),
+            external_task_id=edge_to(dag_id),
             timeout=timeout,
             allowed_states=allowed_states,
             failed_states=failed_states,
@@ -27,8 +31,8 @@ def notify(dag_id, child_dag_ids):
     tasks = []
     for child_id in child_dag_ids:
         tasks.append(ExternalTaskMarker(
-            task_id=task_name(dag_id, child_id),
+            task_id=edge_to(child_id),
             external_dag_id=child_id,
-            external_task_id=task_name(dag_id, child_id),
+            external_task_id=edge_from(dag_id),
         ))
     return tasks
